pub fn flush()Expand description
Flushes the global logger’s internal records.
This simply calls Log::flush() on the current global logger.
If no logger is set, it flushes the default fallback logger.
pub fn flush()Flushes the global logger’s internal records.
This simply calls Log::flush() on the current global logger.
If no logger is set, it flushes the default fallback logger.